# Generated by roxygen2: do not edit by hand

S3method(plot,cipma_analysis)
S3method(plot,coa_analysis)
S3method(plot,cta_analysis)
S3method(plot,fimix_analysis)
S3method(plot,fimix_comparison)
S3method(plot,nca_analysis)
S3method(plot,nca_esse)
S3method(plot,pcm_analysis)
S3method(plot,pos_analysis)
S3method(plot,pos_comparison)
S3method(print,cipma_analysis)
S3method(print,coa_analysis)
S3method(print,cta_analysis)
S3method(print,fimix_analysis)
S3method(print,fimix_comparison)
S3method(print,nca_analysis)
S3method(print,nca_esse)
S3method(print,pcm_analysis)
S3method(print,pos_analysis)
S3method(print,pos_comparison)
S3method(print,summary.cipma_analysis)
S3method(print,summary.coa_analysis)
S3method(print,summary.cta_analysis)
S3method(print,summary.fimix_analysis)
S3method(print,summary.fimix_comparison)
S3method(print,summary.nca_analysis)
S3method(print,summary.nca_esse)
S3method(print,summary.pcm_analysis)
S3method(print,summary.pos_analysis)
S3method(summary,cipma_analysis)
S3method(summary,coa_analysis)
S3method(summary,cta_analysis)
S3method(summary,fimix_analysis)
S3method(summary,fimix_comparison)
S3method(summary,nca_analysis)
S3method(summary,nca_esse)
S3method(summary,pcm_analysis)
S3method(summary,pos_analysis)
S3method(summary,pos_comparison)
export(assess_cipma)
export(assess_coa)
export(assess_cta)
export(assess_cvpat)
export(assess_cvpat_compare)
export(assess_fimix)
export(assess_fimix_compare)
export(assess_ipma)
export(assess_nca)
export(assess_nca_esse)
export(assess_pcm)
export(assess_pos)
export(assess_pos_compare)
export(competes)
export(congruence_test)
export(deviance_tree)
export(group_rules)
export(pos_segments)
export(predictive_deviance)
export(unstable_params)
importFrom(grDevices,adjustcolor)
importFrom(grDevices,palette)
importFrom(grDevices,palette.colors)
importFrom(graphics,abline)
importFrom(graphics,axis)
importFrom(graphics,barplot)
importFrom(graphics,legend)
importFrom(graphics,lines)
importFrom(graphics,matlines)
importFrom(graphics,matplot)
importFrom(graphics,par)
importFrom(graphics,plot)
importFrom(graphics,points)
importFrom(graphics,polygon)
importFrom(graphics,rect)
importFrom(graphics,text)
importFrom(rpart,rpart)
importFrom(seminr,estimate_pls)
importFrom(seminr,mean_replacement)
importFrom(seminr,predict_DA)
importFrom(seminr,predict_EA)
importFrom(seminr,predict_pls)
importFrom(stats,coef)
importFrom(stats,cov)
importFrom(stats,dnorm)
importFrom(stats,lm)
importFrom(stats,median)
importFrom(stats,p.adjust)
importFrom(stats,pt)
importFrom(stats,quantile)
importFrom(stats,sd)
importFrom(stats,t.test)
importFrom(stats,var)
importFrom(utils,combn)
importFrom(utils,head)
