% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/feature_fimix.R
\name{plot.fimix_comparison}
\alias{plot.fimix_comparison}
\title{Plot FIMIX-PLS Comparison}
\usage{
\method{plot}{fimix_comparison}(
  x,
  type = c("criteria", "entropy"),
  criteria = c("AIC3", "AIC4", "BIC", "CAIC"),
  ...
)
}
\arguments{
\item{x}{A \code{fimix_comparison} object from \code{assess_fimix_compare()}.}

\item{type}{One of \code{"criteria"} (line plot of IC vs K) or
\code{"entropy"} (EN vs K).}

\item{criteria}{Character vector of criteria to plot when
\code{type = "criteria"} (default: \code{c("AIC3", "AIC4", "BIC", "CAIC")}).}

\item{...}{Additional arguments passed to \code{plot()}.}
}
\description{
Plot FIMIX-PLS Comparison
}
